cancelable_http_client library
Classes
- CancelableClient
-
A CancelableClient is a wrapper over
Clientthat allows to cancel both a request and the operation of receiving data from the response stream. - CancellationToken
- A CancellationToken is a mechanism for cooperative cancellation of asynchronous operations.
- CancellationTokenSource
-
A CancellationTokenSource class manages the cancellation process for
asynchronous operations.
It works in conjunction with the CancellationToken class, providing acooperativecancellation mechanism.
Extensions
-
StreamExtension
on Stream<
T> - A StreamExtension is an extension for Stream with various useful methods.
Exceptions / Errors
- CancellationException
- Represents an exception used to indicate that the operation was canceled.